// import {gql} from "../utils/getGQL";
import { getGQL } from "../utils/getGQL";
import * as actions from "../constants/actions/index";

const setTracks = (tracks) => ({
  type: actions.SET_TRACKS,
  tracks,
});

export const setCurrentTrack = (trackIndex) => ({
  type: actions.SET_CURRENT_TRACK,
  trackIndex,
});

export const getTracks = () => async (dispatch) => {
  try {
    let response = await getGQL("/graphql", {
      Authorization: `Bearer ${localStorage.authToken}`,
    })(
      // let response = await gql(
      `query tracksFind($query: String){
              TrackFind(query: $query){
                  _id
                  url
                  originalFileName
              }
            }`,
      {
        query: JSON.stringify([
          {},
          {
            limit: [10],
          },
        ]),
      }
    );
    // .then((data) => {
    //   console.log(data)
    // return
    // await dispatch(setTracks(data.data.TrackFind));
    // console.log(response);

    // });
    await dispatch(setTracks(response.data.TrackFind));
    console.log("response.data.TrackFind: ", response.data.TrackFind);
  } catch (error) {
    console.log(error);
  }
};

export const clearTrackList = () => ({
  type: actions.CLEAR_TRACK_LIST,
});

export const getPlaylist = () => async (dispatch) => {
  try {
    // debugger
    let response = await getGQL("/graphql", {
      Authorization: `Bearer ${localStorage.authToken}`,
    })(
      // let response = await gql(
      `query playList{
          PlaylistFind(query:"[{}]"){
            _id
            name
            description
            tracks{
              url
              id3{
              artist
                album
                title
              }
              owner {
                _id
                login
              }
            }
          }
        }`,
      {
        query: JSON.stringify([
          {},
          // {
          //   limit: [10],
          // },
        ]),
      }
    );
    console.log("response in getPlaylist: ", response);
    await dispatch(setPlayList(response.data.PlaylistFind));
  } catch (error) {
    console.log(error);
  }
};

const setPlayList = (playlists) => ({
  type: actions.SET_PLAYLISTS,
  playlists,
});

// export const setTrack = (track) => ({
//   type: actions.SET_TRACK,
//   track,
// });

export const createMyPlaylist = (name, id) => async (dispatch) => {
  console.log("name in action: ", name);
  try {
    let response = await getGQL("/graphql", {
      Authorization: `Bearer ${localStorage.authToken}`,
    })(
      `mutation addPlaylist{
        PlaylistUpsert(playlist:
          { name: "${name}" } ) {_id}
      }`
    );
    console.log(response);
    await dispatch(setMyPlaylist(response.data.PlaylistUpsert));
  } catch (error) {
    console.log(error, "errorr is running");
  }
};

export const setMyPlaylist = (myPlaylist) => ({
  type: actions.CREATE_MY_PLAYLIST,
  myPlaylist,
});

export const findMyPlaylists = () => async (dispatch) => {
  try {
    let response = await getGQL("/graphql", {
      Authorization: `Bearer ${localStorage.authToken}`,
    })(
      `query playlists{
        PlaylistFind(query: "[{\\"___owner\\":\\"${localStorage.id}\\"}]")
        {
          name 
          _id 
          description
            tracks{
                _id
            }}
      }`,
      {
        query: JSON.stringify([{}]),
      }
    );
    console.log(response.data.PlaylistFind);
    await dispatch(setFindMyPlaylists(response.data.PlaylistFind))
  } catch (error) {
    console.log(error);
  }
};

const setFindMyPlaylists = (showMyPlaylists) => ({
  type: actions.FIND_MY_PLAYLISTS,
  showMyPlaylists,
});

export const setTrack = (track) => ({
  type: actions.SET_TRACK,
  track,
});

export const oneTrackFind = (id) => async (dispatch) => {
  try {
    let response = await getGQL("/graphql", {
      Authorization: `Bearer ${localStorage.authToken}`,
    })(
      // let response = await gql(
      `query onePlaylistTracks($query: String!){
        PlaylistFindOne(query: $query){
          _id
          name
          tracks{
            _id
            url
            originalFileName
          }  
        }
      }`,
      {
        query: JSON.stringify([{ _id: id }]),
      }
    ).then((data) => {
      console.log(data);
      return dispatch(
        actionSetTrack(
          data.data.PlaylistFindOne.tracks,
          data.data.PlaylistFindOne.name,
          data.data.PlaylistFindOne._id
        )
      );
    });
    // console.log('response: ', response);
    // dispatch(actionSetTrack(response.data.PlaylistFindOne.tracks, response.data.PlaylistFindOne.name, response.data.PlaylistFindOne._id));
  } catch (error) {}
};

export function actionSetTrack(tracks, playlistTitle, playlistId) {
  return {
    type: "SET_TRACK",
    tracks: tracks == null ? [] : tracks,
    playlistTitle,
    playlistId,
  };
}

export const actionPlaylistTrackPressed = (pressedTracks) => ({
  type: actions.PLAYLIST_TRACK_PRESSED,
  pressedTracks,
});

export const findUser = (login) => async (dispatch) => {
  let response = await getGQL("/graphql", {
    Authorization: `Bearer ${localStorage.authToken}`,
  })(
    `query findUser{
          UserFindOne(query: "[{\\"login\\":\\"${localStorage.user}\\"}]"){ 
              _id
              nick
            login
            createdAt
          }
      }`
  );
  await dispatch(setFindUser(response.data.UserFindOne._id));
  localStorage.id = response.data.UserFindOne._id;
};

export const setFindUser = (userId) => ({
  type: actions.FIND_MY_USER,
  userId,
});
